#----------------------------------------------------------------------------#
# Program Copyright    : Mike Wilcock.
# Program Name         : tb_move.ps1.
#----------------------------------------------------------------------------#
# Program Created      : 27th April 2022.
# Program Code Type    : PowerShell Script (version 5.1.19041.1023).
# Author               : Michael Wilcock, IT Technician.
#----------------------------------------------------------------------------#
# Version              : 1.00
#----------------------------------------------------------------------------#
# Purpose              : Reposition the Windows task bar either top[1], left[0], bottom[3] or right[2].
#----------------------------------------------------------------------------#

clear screen

# Prompt user.
$tb_pos = read-host "Please enter task bar position - Top[1], Left[0], Bottom[3] or Right[2]"

# Very simple validation.
if($tb_pos -eq 0 -or $tb_pos -eq 1 -or $tb_pos -eq 2 -or $tb_pos -eq 3)
{
    # Task bar position registry key.
    $RegistryPath =  'HKCU:\Software\Microsoft\Windows\CurrentVersion\Explorer\StuckRects3'

    # Retreive existing registry value.
    $NewValue = Get-ItemProperty -Path $RegistryPath

    # Set new registry value.
    $NewValue.Settings[12] = $tb_pos

    # Update registry value.
    Set-ItemProperty -Path $RegistryPath -Name "Settings" -Value $NewValue.Settings

    # Stop explorer process.  Will automatically restart.
    Stop-Process -Name "Explorer"
}
# User can't read.
else
{
    clear screen.

    write-host "Invalid input entered - Valid values are: Top[1], Left[0], Bottom[3] or Right[2]"
} 